@@ -8,6 +8,7 @@ import dataclasses
 
 try:
     import numpy as np
+    
 except ImportError:
     np = None
 
@@ -53,25 +54,28 @@ def object_serializer(obj: typing.Any) -> typing.Any:
     if isinstance(obj, dict):
         return {k: object_serializer(v) for k, v in obj.items()}
 
+    if isinstance(obj, list):
+        return [object_serializer(v) for v in obj]    
+
     if isinstance(obj, bytes):
         return obj.decode('utf-8')
-
-    if isinstance(obj, (str, list, dict, int, float, bool, type(None))):
+    
+    if isinstance(obj, (str, int, float, bool, type(None))):
         return obj
 
-    if dataclasses.is_dataclass(obj):
-        return dataclasses.asdict(obj)
-
     if hasattr(obj, 'dict'): # test for pydantic models
         return obj.dict()
     
+    if dataclasses.is_dataclass(obj):
+        return dataclasses.asdict(obj)
+
     # Custom dict methods
     if hasattr(obj, 'to_dict'):
         return obj.to_dict()
     
     if hasattr(obj, 'todict'):
         return obj.todict()
-    
+
     if hasattr(obj, 'get_secret_value'):
         return obj.get_secret_value()
     
@@ -107,6 +111,7 @@ def object_serializer(obj: typing.Any) -> typing.Any:
         with contextlib.suppress(Exception):
             return float(obj)
 
+
     raise TypeError(f"Object of type {type(obj)} is not JSON serializable")
 
 
@@ -153,7 +158,11 @@ class ObjectEncoder(json.JSONEncoder):
     
     def default(self, obj: typing.Any):   # pylint: disable=arguments-differ,method-hidden
         with contextlib.suppress(Exception):
-            return object_serializer(obj)
+           return object_serializer(obj)
+        # try:
+        #     return object_serializer(obj)
+        # except TypeError:
+        #     print(f"Object of type {type(obj)} is not JSON serializable: {obj}")
         return json.JSONEncoder.default(self, obj)
 
 class ObjectDecoder(json.JSONDecoder):
